@@ -1,5 +1,5 @@
 package Text::ANSI::Fold::Util;
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 use v5.14;
 use utf8;
@@ -32,7 +32,7 @@ Text::ANSI::Fold::Util - Text::ANSI::Fold utilities (width, substr)
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 DESCRIPTION
 
@@ -76,13 +76,23 @@ sub width {
 
 Returns substring just like Perl's B<substr> function, but string
 position is calculated by the visible width on the screen instead of
-number of characters.
+number of characters.  If there is no corresponding substring, undef
+is returned always.
 
-If an optional I<replacement> parameter is given, replace the substring
-by the replacement and return the entire string.
+If the C<padding> option is specified, then if there is a
+corresponding substring, it is padded to the specified width and
+returned.
 
-It does not cut the text in the middle of multi-byte character, of
-course.  Its behavior depends on the implementation of lower module.
+It does not cut the text in the middle of multi-byte character.  If
+you want to split the text in the middle of a wide character, specify
+the C<crackwide> option.
+
+    Text::ANSI::Fold->configure(crackwide => 1);
+
+If an optional I<replacement> parameter is given, replace the
+substring by the replacement and return the entire string.  If 0 is
+specified for the width, there may be no error even if the
+corresponding substring does not exist.
 
 =cut
 
@@ -98,7 +108,11 @@ sub substr {
 	->text($text)
 	->chops(width => [ $offset, $length // -1, -1 ]);
     if (defined $replacement) {
-	$s[0] . $replacement . ($s[2] // '');
+	if (defined $s[1]) {
+	    $s[0] . $replacement . ($s[2] // '');
+	} else {
+	    undef;
+	}
     } else {
 	$s[1];
     }
